@@ -147,7 +147,6 @@ application_cannot_open_location (GnomeVFSMimeApplication *application,
 		
 		message_dialog = eel_show_yes_no_dialog (prompt, 
 		                                         message,
-							 _("Can't Open Location"), 
 							 GTK_STOCK_OK,
 							 GTK_STOCK_CANCEL,
 							 parent_window);
@@ -180,7 +179,7 @@ application_cannot_open_location (GnomeVFSMimeApplication *application,
 				    "it.");
 		}
 				
-		eel_show_info_dialog (prompt, message, _("Can't Open Location"), parent_window);
+		eel_show_info_dialog (prompt, message, parent_window);
 		g_free (prompt);
 	}	
 
@@ -643,7 +642,7 @@ void nautilus_launch_show_file (NautilusFile *file,
 	}
 
 	if (error_message != NULL) {
-		eel_show_error_dialog (error_message, detail_message, _("Can't Display Location"), parent_window);
+		eel_show_error_dialog (error_message, detail_message, parent_window);
 		
 		g_free (error_message);
 		g_free (detail_message);
@@ -665,18 +664,19 @@ void nautilus_launch_show_file (NautilusFile *file,
  * parameter. Provide a parent window for error dialogs. 
  * 
  * @application: The application to be launched.
- * @file: The file whose location should be passed as a parameter to the application
+ * @files: The files whose locations should be passed as a parameter to the application.
  * @parent_window: A window to use as the parent for any error dialogs.
  */
 void
 nautilus_launch_application (GnomeVFSMimeApplication *application, 
-			     NautilusFile *file,
+			     GList *files,
 			     GtkWindow *parent_window)
 {
 	GdkScreen       *screen;
 	char		*uri;
 	char            *uri_scheme;
-	GList            uris;
+	GList           *uris, *l;
+	NautilusFile    *file;
 	char           **envp;
 	GnomeVFSResult   result;
 #ifdef HAVE_STARTUP_NOTIFICATION
@@ -684,19 +684,26 @@ nautilus_launch_application (GnomeVFSMimeApplication *application,
 	SnDisplay *sn_display;
 #endif
 
-	uri = NULL;
-	if (nautilus_file_is_nautilus_link (file)) {
-		uri = nautilus_file_get_activation_uri (file);
+	g_assert (files != NULL);
+
+	uris = NULL;
+	for (l = files; l != NULL; l = l->next) {
+		file = NAUTILUS_FILE (l->data);
+
+		uri = NULL;
+
+		if (nautilus_file_is_nautilus_link (file)) {
+			uri = nautilus_file_get_activation_uri (file);
+		}
+		
+		if (uri == NULL) {
+			uri = nautilus_file_get_uri (file);
+		}
+
+		uris = g_list_prepend (uris, uri);
 	}
-	
-	if (uri == NULL) {
-		uri = nautilus_file_get_uri (file);
-	}
+	uris = g_list_reverse (uris);
 
-	uris.next = NULL;
-	uris.prev = NULL;
-	uris.data = uri;
-	
 	screen = gtk_window_get_screen (parent_window);
 	envp = my_gdk_spawn_make_environment_for_screen (screen, NULL);
 	
@@ -710,27 +717,44 @@ nautilus_launch_application (GnomeVFSMimeApplication *application,
 	if (gnome_vfs_mime_application_supports_startup_notification (application))
 	{ 
 		char *name;
+		char *description;
 		char *icon;
+		int   files_count;
+
+		file = NAUTILUS_FILE (files->data);
 
 		sn_context = sn_launcher_context_new (sn_display,
 						      screen ? gdk_screen_get_number (screen) :
 						      DefaultScreen (gdk_display));
-		
-		name = nautilus_file_get_display_name (file);
-		if (name != NULL) {
-			char *description;
-			
-			sn_launcher_context_set_name (sn_context, name);
-			
-			description = g_strdup_printf (_("Opening %s"), name);
-			
-			sn_launcher_context_set_description (sn_context, description);
 
+		files_count = g_list_length (files);
+		if (files_count == 1) {
+			name = nautilus_file_get_display_name (file);
+			description = g_strdup_printf (_("Opening %s"), name);
+		} else {
+			name = NULL;
+			description = g_strdup_printf (ngettext ("Opening %d Item",
+								 "Opening %d Items",
+								 files_count),
+						       files_count);
+		}
+
+		if (name != NULL) {
+			sn_launcher_context_set_name (sn_context, name);
 			g_free (name);
+		}
+
+		if (description != NULL) {
+			sn_launcher_context_set_description (sn_context, description);
 			g_free (description);
 		}
 
 		icon = nautilus_icon_factory_get_icon_for_file (file, FALSE);
+
+		if (icon == NULL) {
+			icon = g_strdup (gnome_vfs_mime_application_get_icon (application));
+		}
+
 		if (icon != NULL) {
 			sn_launcher_context_set_icon_name (sn_context, icon);
 			g_free (icon);
@@ -762,7 +786,7 @@ nautilus_launch_application (GnomeVFSMimeApplication *application,
 	}
 #endif /* HAVE_STARTUP_NOTIFICATION */
 	
-	result = gnome_vfs_mime_application_launch_with_env (application, &uris, envp);
+	result = gnome_vfs_mime_application_launch_with_env (application, uris, envp);
 
 #ifdef HAVE_STARTUP_NOTIFICATION
 	if (sn_context != NULL) {
@@ -784,7 +808,7 @@ nautilus_launch_application (GnomeVFSMimeApplication *application,
 		break;
 
 	case GNOME_VFS_ERROR_NOT_SUPPORTED:
-		uri_scheme = nautilus_file_get_uri_scheme (file);
+		uri_scheme = nautilus_file_get_uri_scheme (NAUTILUS_FILE (files->data));
 		application_cannot_open_location (application,
 						  file,
 						  uri_scheme,
@@ -801,8 +825,8 @@ nautilus_launch_application (GnomeVFSMimeApplication *application,
 #endif
 		break;
 	}
-	
-	g_free (uri);
+
+	eel_g_list_free_deep (uris);
 	g_strfreev (envp);
 }
 
@@ -877,7 +901,6 @@ nautilus_launch_desktop_file (GdkScreen   *screen,
 			(_("Sorry, but you can't execute commands from "
 			   "a remote site."), 
 			 _("This is disabled due to security considerations."),
-			 _("Can't Execute Remote Links"),
 			 parent_window);
 			 
 		return;
@@ -891,7 +914,6 @@ nautilus_launch_desktop_file (GdkScreen   *screen,
 		eel_show_error_dialog
 			(_("There was an error launching the application."),
 			 message,
-			 _("Error Launching Application"),
 			 parent_window);			
 			 
 		g_error_free (error);
@@ -922,7 +944,6 @@ nautilus_launch_desktop_file (GdkScreen   *screen,
 				(_("This drop target only supports local files."),
 				 _("To open non-local files copy them to a local folder and then"
 				   " drop them again."),
-				 _("Drop Target Only Supports Local Files"),
 				 parent_window);
 			
 			gnome_desktop_item_unref (ditem);
@@ -934,7 +955,6 @@ nautilus_launch_desktop_file (GdkScreen   *screen,
 				(_("This drop target only supports local files."),
 				 _("To open non-local files copy them to a local folder and then"
 				   " drop them again. The local files you dropped have already been opened."),
-				 _("Drop Target Only Supports Local Files"),
 				 parent_window);
 		}		
 	}
@@ -962,7 +982,6 @@ nautilus_launch_desktop_file (GdkScreen   *screen,
 		eel_show_error_dialog
 			(_("There was an error launching the application."),
 			 message,
-			 _("Error Launching Application"),
 			 parent_window);			
 			 
 		g_error_free (error);
