@@ -959,7 +959,7 @@ remove_pattern(NautilusPropertyBrowser *property_browser, const char* pattern_na
 	if (gnome_vfs_unlink (pattern_uri) != GNOME_VFS_OK) {
 		char *message = g_strdup_printf (_("Sorry, but pattern %s couldn't be deleted."), pattern_name);
 		char *detail = _("Check that you have permission to delete the pattern.");
-		eel_show_error_dialog (message, detail, _("Couldn't Delete Pattern"), GTK_WINDOW (property_browser));
+		eel_show_error_dialog (message, detail, GTK_WINDOW (property_browser));
 		g_free (message);
 	}
 	
@@ -989,7 +989,7 @@ remove_emblem (NautilusPropertyBrowser *property_browser, const char* emblem_nam
 	if (gnome_vfs_unlink (emblem_uri) != GNOME_VFS_OK) {
 		char *message = g_strdup_printf (_("Sorry, but emblem %s couldn't be deleted."), emblem_name);
 		char *detail = _("Check that you have permission to delete the emblem.");
-		eel_show_error_dialog (message, detail, _("Couldn't Delete Emblem"), GTK_WINDOW (property_browser));
+		eel_show_error_dialog (message, detail, GTK_WINDOW (property_browser));
 		g_free (message);
 	}
 	else {
@@ -1023,24 +1023,35 @@ nautilus_property_browser_remove_element (NautilusPropertyBrowser *property_brow
 static GtkWidget*
 nautilus_emblem_dialog_new (NautilusPropertyBrowser *property_browser)
 {
+	GtkWidget *hbox;
 	GtkWidget *widget;
 	GtkWidget *dialog;
 	GtkWidget *table = gtk_table_new(2, 2, FALSE);
 
-	dialog = gtk_dialog_new_with_buttons (_("Create a New Emblem:"),
+	dialog = gtk_dialog_new_with_buttons (_("Create a New Emblem"),
 					      GTK_WINDOW (property_browser), 0,
 					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					      GTK_STOCK_OK, GTK_RESPONSE_OK,
 					      NULL);
 
 	/* install the table in the dialog */	
-	gtk_widget_show (table);	
+	gtk_container_set_border_width (GTK_CONTAINER (table), 5);
+	gtk_table_set_row_spacings (GTK_TABLE (table), 6);
+	gtk_table_set_col_spacings (GTK_TABLE (table), 12);	
+	gtk_widget_show (table);
+
+	gtk_window_set_resizable (GTK_WINDOW (dialog), TRUE);
+	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
+	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 2);
+	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
+	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), table, TRUE, TRUE, 0);
 	gtk_dialog_set_default_response (GTK_DIALOG(dialog), GTK_RESPONSE_OK);
 
 	/* make the keyword label and field */	
 	
 	widget = gtk_label_new_with_mnemonic(_("_Keyword:"));
+	gtk_misc_set_alignment (GTK_MISC (widget), 0, 0.5);
 	gtk_widget_show(widget);
 	gtk_table_attach(GTK_TABLE(table), widget, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
 	
@@ -1059,10 +1070,14 @@ nautilus_emblem_dialog_new (NautilusPropertyBrowser *property_browser)
 	
 	/* set up a gnome icon entry to pick the image file */
 	widget = gtk_label_new_with_mnemonic (_("_Image:"));
+	gtk_misc_set_alignment (GTK_MISC (widget), 0, 0.5);
 	gtk_widget_show(widget);
 	gtk_table_attach(GTK_TABLE(table), widget, 0, 1, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
 
-	property_browser->details->file_entry = gnome_icon_entry_new (NULL, _("Select an image file for the new emblem:"));
+	hbox = gtk_hbox_new (FALSE, 0);
+	gtk_widget_show (hbox);
+
+	property_browser->details->file_entry = gnome_icon_entry_new (NULL, _("Select an Image File for the New Emblem"));
 	gnome_icon_entry_set_pixmap_subdir (GNOME_ICON_ENTRY(property_browser->details->file_entry),
 						DATADIR "/pixmaps");
 	gnome_icon_entry_set_filename (GNOME_ICON_ENTRY(property_browser->details->file_entry),
@@ -1071,7 +1086,8 @@ nautilus_emblem_dialog_new (NautilusPropertyBrowser *property_browser)
 				       GTK_WIDGET (property_browser->details->file_entry));
 
 	gtk_widget_show(property_browser->details->file_entry);
-	gtk_table_attach(GTK_TABLE(table), property_browser->details->file_entry, 1, 2, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
+	gtk_table_attach(GTK_TABLE(table), hbox, 1, 2, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (property_browser->details->file_entry), FALSE, FALSE, 0);
 	
 	gnome_icon_entry_set_filename (GNOME_ICON_ENTRY (property_browser->details->file_entry), property_browser->details->image_path);	
 	return dialog;
@@ -1154,7 +1170,7 @@ add_pattern_to_browser (const char *path_name, gpointer *data)
 			message = g_strdup (_("Sorry, but you did not supply a valid file name."));
 			detail = _("Please try again.");
 		}
-		eel_show_error_dialog (message, detail, _("Couldn't Install Pattern"), GTK_WINDOW (property_browser));
+		eel_show_error_dialog (message, detail, GTK_WINDOW (property_browser));
 		g_free (message);
 		return;
 	}
@@ -1167,7 +1183,7 @@ add_pattern_to_browser (const char *path_name, gpointer *data)
 	if (basename && eel_strcmp (basename, RESET_IMAGE_NAME) == 0) {
 		eel_show_error_dialog (_("Sorry, but you can't replace the reset image."), 
 		                       _("Reset is a special image that cannot be deleted."), 
-		                       _("Not an Image"), NULL);
+		                       NULL);
 		g_free (path_uri);
 		g_free (basename);
 		return;
@@ -1199,7 +1215,7 @@ add_pattern_to_browser (const char *path_name, gpointer *data)
 	result = eel_copy_uri_simple (path_name, destination_name);		
 	if (result != GNOME_VFS_OK) {
 		char *message = g_strdup_printf (_("Sorry, but the pattern %s couldn't be installed."), path_name);
-		eel_show_error_dialog (message, NULL, _("Couldn't Install Pattern"), GTK_WINDOW (property_browser));
+		eel_show_error_dialog (message, NULL, GTK_WINDOW (property_browser));
 		g_free (message);
 	}
 		
@@ -1218,7 +1234,7 @@ add_new_pattern (NautilusPropertyBrowser *property_browser)
 		gtk_window_present (GTK_WINDOW (property_browser->details->patterns_dialog));
 	} else {
 		property_browser->details->patterns_dialog = 
-			eel_gnome_icon_selector_new (_("Select an image file to add as a pattern"),
+			eel_gnome_icon_selector_new (_("Select an Image File to Add as a Pattern"),
 				DATADIR "/nautilus/patterns/",
 				GTK_WINDOW (property_browser),
 				(EelIconSelectionFunction) add_pattern_to_browser,
@@ -1272,7 +1288,7 @@ add_color_to_file (NautilusPropertyBrowser *property_browser, const char *color_
 		} else {
 			eel_show_error_dialog (_("The color cannot be installed."),
 					       _("Sorry, but you must specify an unused color name for the new color."), 
-			                       _("Couldn't Install Color"), GTK_WINDOW (property_browser));
+			                       GTK_WINDOW (property_browser));
 		}
 	}
 	
@@ -1303,7 +1319,7 @@ add_color_to_browser (GtkWidget *widget, gint which_button, gpointer *data)
 		if (strlen (stripped_color_name) == 0) {
 			eel_show_error_dialog (_("The color cannot be installed."),
 					       _("Sorry, but you must specify a non-blank name for the new color."), 
-			                       _("Couldn't Install Color"), GTK_WINDOW (property_browser));
+			                       GTK_WINDOW (property_browser));
 		
 		} else {
 			add_color_to_file (property_browser, color_spec, stripped_color_name);
@@ -1355,7 +1371,7 @@ add_new_color (NautilusPropertyBrowser *property_browser)
 	} else {
 		GtkColorSelectionDialog *color_dialog;
 
-		property_browser->details->colors_dialog = gtk_color_selection_dialog_new (_("Select a color to add"));
+		property_browser->details->colors_dialog = gtk_color_selection_dialog_new (_("Select a Color to Add"));
 		color_dialog = GTK_COLOR_SELECTION_DIALOG (property_browser->details->colors_dialog);
 		
 		eel_add_weak_pointer (&property_browser->details->colors_dialog);
@@ -1393,7 +1409,7 @@ emblem_dialog_clicked (GtkWidget *dialog, int which_button, NautilusPropertyBrow
 				} else {
 					char *message = g_strdup_printf
 						(_("Sorry, but \"%s\" is not a usable image file."), emblem_path);
-					eel_show_error_dialog (_("The file is not an image."), message, _("Not an Image"), GTK_WINDOW (property_browser));
+					eel_show_error_dialog (_("The file is not an image."), message, GTK_WINDOW (property_browser));
 					g_free (message);
 					g_free (emblem_path);
 					return;
@@ -1409,7 +1425,7 @@ emblem_dialog_clicked (GtkWidget *dialog, int which_button, NautilusPropertyBrow
 		if (pixbuf == NULL) {
 			char *message = g_strdup_printf
 				(_("Sorry, but \"%s\" is not a usable image file."), property_browser->details->image_path);
-			eel_show_error_dialog (_("The file is not an image."), message, _("Not an Image"), GTK_WINDOW (property_browser));
+			eel_show_error_dialog (_("The file is not an image."), message, GTK_WINDOW (property_browser));
 			g_free (message);
 		}
 		
